{% extends "base.html" %}
{% from "macros/ui.html" import log_table %}
{% block title %}Logs — Hassette{% endblock %}
{% block content %}
  <h1 class="ht-heading-4">
    <span class="ht-icon"><i class="fas fa-scroll"></i></span>
    <span>Log Viewer</span>
  </h1>
  <div class="ht-card">{{ log_table(show_app_column=true, app_keys=app_keys) }}</div>
{% endblock %}
