{% extends "base.html" %}
{% block title %}{{ status_code }} — Hassette{% endblock %}
{% block content %}
  <div class="ht-text-center ht-p-hero">
    <h1 class="ht-heading-1">{{ status_code }}</h1>
    <h2 class="ht-subheading-4">{{ detail }}</h2>
    <a href="/ui/" class="ht-btn ht-btn--primary ht-mt-4">
      <span class="ht-icon"><i class="fas fa-home"></i></span>
      <span>Back to Dashboard</span>
    </a>
  </div>
{% endblock %}
