<div class="ht-status-bar" x-data>
  <button class="ht-menu-toggle"
          @click="sidebarOpen = !sidebarOpen"
          aria-label="Toggle menu">
    <span class="ht-icon"><i class="fas fa-bars"></i></span>
  </button>
  <span class="ht-ws-indicator"
        :class="$store.ws.connected ? 'is-connected' : 'is-disconnected'">
    <span class="ht-pulse-dot"
          :class="$store.ws.connected ? '' : 'ht-pulse-dot--disconnected'"></span>
    <span class="ht-text-xs"
          x-text="$store.ws.connected ? 'Connected' : 'Disconnected'"></span>
  </span>
</div>
